#PCA on abiotic variables
#prism database, 800m resolution, annual values

setwd("C:/Users/Jeremiah/Dropbox/F2 Hybrid Breakdown/manuscript/env_distance/")
df=read.csv('prism_annual.csv', header=T)

#examine correlations
library(PerformanceAnalytics)
chart.Correlation(df[,4:ncol(df)])

#temperature all highly correlated, just choose mean
vars = df[,c(4,5,7,10,11)]
df.pca <- prcomp(vars, center = TRUE,scale. = TRUE)

#PC1=66%, PC2=19%, PC3=11%
df$PC1 = df.pca$x[,1]
df$PC2 = df.pca$x[,2]
df$PC3 = df.pca$x[,3]
df$PC4 = df.pca$x[,4]
df$PC5 = df.pca$x[,5]

#save raw data and PCs
write.csv(df, 'df_5PCs.csv', row.names = F)

#get multivariate mahalanobis 
pcs = df[,12:16]

#Euclidean distance between points
dist(pcs, method="euclidean", diag=F, upper=F)

#pairwise Mahalanobis distance between points
library(biotools)
Sx = cov(pcs)
distD2 = D2.dist(pcs, Sx)

#on raw data
#Euclidean, stored as raw_Euclid
dist(vars, method="euclidean", diag=F, upper=F)

#Mahalanobis, stored as raw_Mah
Sx = cov(vars)
distD2a = D2.dist(vars,Sx) 

#read file with distances, which were input by hand from the env. distance matrices
#pairwise_D_rawvars for distances on raw variables -raw_Euclid and raw_Mah
#pairwise_D_PCs for distances on PCs --EuclidD and MahalanobisD
file = read.csv('4glm.csv', header=T)

#add lat and long to file -- population names are ordered the same
file$lat = df$Latitude
file$long = df$Longitude

#plot distances
plot(file$raw_Euclid, file$raw_Mah, pch=19, xlab='Euclidean distance', ylab='Mahalanobis distance')

#without env. distance
fit = glm(file$ALLpopFITnoBdelta.F2 ~ file$haversine+file$Fst+file$thetawMP)
file$resids = fit$residuals

#plot
plot(file$raw_Euclid, file$resids, pch=19, xlab="pairwise Euclidean distance", ylab="residual delta/F2")
plot(file$raw_Mah,file$resids, pch=19, xlab="pairwise Mahalanobis distance", ylab="residual delta/F2")
fit2 = glm(file$ALLpopFITnoBdelta.F2 ~ file$haversine+file$Fst+file$thetawMP+file$raw_Euclid)
fit3 = glm(file$ALLpopFITnoBdelta.F2 ~ file$haversine+file$Fst+file$thetawMP+file$raw_Mah)

#fits
library(rsq)
rsq(fit)
rsq(fit2)
rsq(fit3)

#corrplot
see = file[,c(3,19,20,22,23,24)]
library(PerformanceAnalytics)
chart.Correlation(see)

pcs = file[,c(12:16)]
chart.Correlation(pcs)

#LFG suggestion: remove geo distance -- since analysis now has both env and genetics, geo dist might eat up some of these latter variance components
fit = glm(file$ALLpopFITnoBdelta.F2 ~ file$Fst+file$thetawMP)
file$resids = fit$residuals

#plot
plot(file$raw_Euclid, file$resids, pch=19, xlab="pairwise Euclidean distance", ylab="residual delta/F2")
plot(file$raw_Mah,file$resids, pch=19, xlab="pairwise Mahalanobis distance", ylab="residual delta/F2")
fit2 = glm(file$ALLpopFITnoBdelta.F2 ~ file$Fst+file$thetawMP+file$raw_Euclid)
fit3 = glm(file$ALLpopFITnoBdelta.F2 ~ file$Fst+file$thetawMP+file$raw_Mah)

library(rsq)
rsq(fit)
rsq(fit2)
rsq(fit3)


