#0. Follow below routine for 1000 jackknife 3 datasets
#1. Consider each maternal population
#2. Consider each cross type (parents, F1, F2)
#3. Jackknife individuals, get individual fitness
#     --1-2 plants, to have ~20% deleted in each pop*cross combo 
#4. Calculate sample means (parents, F1, F2)
#5. Calculate F2 breakdown, add to distribution
#      see 'calc breakdown - SAS' for equations
#6. Calculate SD in the measures to examine within-cross variation

#Make 1000 jackknife datasets
setwd('C:/Users/Jeremiah/Dropbox/F2 Hybrid Breakdown/manuscript/resampling/')
f1 = read.csv('F1_fitness.csv', header=T)
f2 = read.csv('F2_fitness.csv', header=T)
f2 = f2[,1:10]
#remove plants that did not bolt
f1 = f1[f1$Bolt==1,]
f2 = f2[f2$Bolt==1,]
#reorder columns and match for row binding
f1 = f1[,c(1,3,2,4,5,6,8,10)]
f2 = f2[,c(1,2,3,4,5,6,8,10)]

#convert '.' to NA for fitness
f1$IndivFITnoB[f1$IndivFITnoB == "."] <- NA
f2$indivFITnoB[f2$indivFITnoB == "."] <- NA

#remove those rows
f1 = f1[!is.na(f1$IndivFITnoB),]
f2 = f2[!is.na(f2$indivFITnoB),]

#investigate sample sizes in f1 and f2 to see if jacknife needs to be customized
table(f1$POP) #MI127 has 20, while all others are 30+; jack = 1 for MI127
table(f2$POP) #MI127 and MN117 have 20-25, all others over that

#global variables: number of datasets to make; jacknife is dynamic because of variable sample sizes
reps = 1000

#collect the jackknife samples
samples=data.frame(ID=numeric(), pop=character(), type=character(), germ=numeric(), surv=numeric(), bolt=numeric(),meanflw=numeric(),indfit=numeric(), data=character(), rep=numeric(), stringsAsFactors = F)
for(i in 1:reps){
#1. Consider each maternal population
#2. Consider each cross type (B, W)
#3. Jackknife 3 individuals, get individual fitness
for(j in unique(f1$POP)){
  popf1 = f1[f1$POP==j,]
  popf2 = f2[f2$POP==j,]
  #rows of F1 B plants
  popf1B = subset(popf1, popf1$TYPE=='B')
  jack=2
  if(j=="MI_127"){jack=1}
  tempB1=popf1B[-sort(ceiling(runif(jack, 1, nrow(popf1B)))),]
  tempB1$data = 'F1'
  tempB1$rep = i
  #rows of F1 W plants
  popf1W = subset(popf1, popf1$TYPE=='W')
  jack=2
  if(j=="MI_127"){jack=1}
  tempW1=popf1W[-sort(ceiling(runif(jack, 1, nrow(popf1W)))),]
  tempW1$data = 'F1'
  tempW1$rep=i
  #rows of F2 B plants
  popf2B = subset(popf2, popf2$TYPE=='B')
  jack=2
  if(j=="IN_77"|j=="MI_126"|j=="MI_127"|j=="MN_117"|j=="OH_119"|j=="OH_64"|j=="PA_27"){jack=1}
  tempB2=popf2B[-sort(ceiling(runif(jack, 1, nrow(popf2B)))),]
  tempB2$data = 'F2'
  tempB2$rep = i
  #rows of F2 B plants
  popf2W = subset(popf2, popf2$TYPE=='W')
  jack=2
  if(j=="IN_77"|j=="MI_126"|j=="MI_127"|j=="MN_117"|j=="OH_119"|j=="OH_64"|j=="PA_27"){jack=1}
  tempW2=popf2W[-sort(ceiling(runif(jack, 1, nrow(popf2W)))),]
  tempW2$data = 'F2'
  tempW2$rep = i
  colnames(tempB1)=colnames(tempB2)=colnames(tempW1)=colnames(tempW2)=colnames(samples)
  samples = rbind(samples, tempB1,tempW1,tempB2,tempW2)
  }
}
write.csv(samples, '1Kreplicates_noB.csv', row.names=F)

#convert to numeric for math
samples$indfit=as.numeric(samples$indfit)

#4. Calculate sample means (parents, F1, F2) for each replicate
output = data.frame(rep=numeric(), pop=character(), parent=numeric(), f1=numeric(), f2=numeric(), stringsAsFactors = F)
#consider each replicate
for(i in 1:max(samples$rep)){
  for(j in unique(samples$pop)){
    temp=subset(samples, samples$rep==i & samples$pop==j)
    parent=subset(temp, temp$type=='W')
    f1=subset(temp, temp$data=='F1' & temp$type=='B')
    f2=subset(temp, temp$data=='F2' & temp$type=='B')
    output[nrow(output)+1,] = c(i,j,mean(parent$indfit, na.rm=T),mean(f1$indfit, na.rm=T),mean(f2$indfit, na.rm=T))
}}
write.csv(output, '1Kmeans_noB.csv', row.names=F)
output=read.csv('1Kmeans_noB.csv', header=T)
#5. Calculate F2 breakdown, add to distribution
#get paternal population to calculate fitnesses
keys = read.csv('pairings.csv',header=T)
colnames(output)[2]='dam'

#remove underscore from output names so they match
library(stringr)
output$dam = str_remove(output$dam, '_')

#add sire population from pairings datafile
output$sire = NA
for(i in 1:nrow(output)){
  output[i,]$sire = keys[keys$dam==output[i,]$dam,]$sire
}

#now add the sire parent mean from the same replicate clarity
output$parent2 = NA
for(i in 1:nrow(output)){
  #make sure it's the same replicate datafile to find sire parental mean
  slice = subset(output,output$rep==output[i,]$rep)
  #write down the sire parental fitness, because it was also a dam elsewhere
  output[i,]$parent2 = slice[slice$dam==output[i,]$sire,]$parent
}

#make sure columns numeric before math
output$parent = as.numeric(output$parent)
output$f1 = as.numeric(output$f1)
output$f2 = as.numeric(output$f2)
output$parent2 = as.numeric(output$parent2)

#add new column to store deltaF2 
output$MP = NA
output$f1_MP = NA
output$delta = NA

#calculate breakdown: see 'calc breakdown - SAS' for equations
output$MP = (output$parent+output$parent2)/2
output$f1_MP = (output$f1+output$MP)/2
output$delta = output$f2-output$f1_MP
output$delta_f2 = output$delta/output$f2

#final output of variability
final = data.frame(dam=character(), sire=character(), p1=numeric(),p2=numeric(),f1=numeric(),f2=numeric(),delta=numeric(),delta_f2=numeric(),p1SD=numeric(),p2SD=numeric(), f1SD=numeric(),f2SD=numeric(), deltaSD=numeric(),delta_f2SD=numeric(), stringsAsFactors = F)
for(i in unique(output$dam)){
  temp = subset(output, output$dam==i)
  dad = unique(temp$sire)
  final[nrow(final)+1,]=c(i,dad,mean(temp$parent),mean(temp$parent2),mean(temp$f1),mean(temp$f2),mean(temp$delta),mean(temp$delta_f2), sd(temp$parent), sd(temp$parent2),sd(temp$f1),sd(temp$f2),sd(temp$delta),sd(temp$delta_f2))
}
write.csv(final, '1Kbreakdown_means_SD_noB.csv', row.names = F)

#final = read.csv('1Kbreakdown_means_SD_noB.csv', header=T)
#convert to numeric
final$delta_f2SD = as.numeric(final$delta_f2SD)
final$delta_f2 = as.numeric(final$delta_f2)

#compare replicate data to real data
library(stringr)
real = read.csv('realmeans.csv', header=T)
real$Pop = str_remove(real$Pop, '_')

#make sure population IDs match between the resampled and real data
real$Pop == final$dam

#check that resample mean matches the real mean
plot(final$delta_f2~real$ALLpopFITnoBdelta.F2, ylab=expression(paste("Resampled mean (", Delta, "/F2)")), xlab=expression(paste("Real mean (", Delta, "/F2)")), pch=20)
abline(0,1)

#one population is kinda deviant -- smaller samples? AR125xTN19 is most deviant
final$real_meanf2 = real$ALLpopFITnoBdelta.F2

#look at variation in fitness measures in parents, f1, f2
cross = final[,9:(ncol(final)-1)]
cross <- sapply( cross, as.numeric )
colnames(cross) = c("dam","sire","F1","F2","Delta","Delta/F2")

#coefficients of variation
numbs = final[,3:ncol(final)]
colnames(numbs) = colnames(final)[3:14]
numbs <- sapply( numbs, as.numeric )
numbs = as.data.frame(numbs)
numbs$CVp1 = 100*(numbs$p1SD/numbs$p1)
numbs$CVp2 = 100*(numbs$p2SD/numbs$p2)
numbs$CVf1 = 100*(numbs$f1SD/numbs$f1)
numbs$CVf2 = 100*(numbs$f2SD/numbs$f2)
means = numbs[,14:17]
colnames(means) = c("dam","sire","F1","F2")
boxplot(means, ylab="Coefficient of fitness variation", xlab="Cross")

crosses = read.csv('crosses.csv', header=T)

#parents vs. f1
crosses[(crosses$cross=='dam')|(crosses$cross=='sire'),]$cross <- 'parents'
one = subset(crosses, crosses$cross!="F2")
two = subset(crosses, crosses$cross!="parents")
res <- var.test(SD ~ cross, data = one)
res <- var.test(SD ~ cross, data = two)


#greater variation in breakdown in populations with the most breakdown?
plot(final$delta_f2SD~real$ALLpopFITnoBdelta.F2, lwd=5, ylab = expression(paste("Resampled SD (", Delta, "/F2)")), xlab= expression(paste("Real mean (", Delta, "/F2)")),pch=20)
fit = glm(final$delta_f2SD~final$real_meanf2)
library(car)
outlierTest(fit)

#get sample sizes for f1 and f2
final$f1sample = table(f1$POP)
final$f2sample = table(f2$POP)

#get the relative amounts
final$prop_del_f1 = NA
final$prop_del_f2 = NA

for(i in 1:nrow(final)){
  final[i,]$prop_del_f1 = 4/final[i,]$f1sample
  if(final[i,]$dam=='MI127'){final[i,]$prop_del_f1 = 2/final[i,]$f1sample}
}

for(i in 1:nrow(final)){
  final[i,]$prop_del_f2 = 4/final[i,]$f2sample
  if(final[i,]$dam=='MI127'|final[i,]$dam=='MN117'|final[i,]$dam=='MI126'|final[i,]$dam=='PA27'|final[i,]$dam=='OH64'|final[i,]$dam=='OH119'|final[i,]$dam=='IN77'){final[i,]$prop_del_f2 = 2/final[i,]$f2sample}
}
write.csv(final, '1Kbreakdown_means_SD_noB.csv', row.names = F)

#remove significant outlier
final=final[final$delta_f2SD<0.07,]
real = real[real$Pop!='OH119',]

#greater variation in breakdown in populations with the most breakdown?
plot(final$delta_f2SD~real$ALLpopFITnoBdelta.F2, cex=1.3, pch=19,ylab = expression(paste("Resampled SD (", Delta, "/F2)")), xlab= expression(paste("Real mean (", Delta, "/F2)")))
fit = glm(final$delta_f2SD~final$real_meanf2)
lines(sort(final$real_meanf2), fitted(fit)[order(final$real_meanf2)], col='black')
outlierTest(fit)

library(rsq)
